@@ -463,17 +463,21 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	if (DETAIL ("menubar") && !ge_is_panel_widget_item(widget))
+	if (DETAIL ("menubar"))
 	{
 		WidgetParameters params;
 		MenuBarParameters menubar;
+		gboolean horizontal;
 
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
 		menubar.style = clearlooks_style->menubarstyle;
 
-		STYLE_FUNCTION(draw_menubar) (cr, colors, &params, &menubar,
-		                              x, y, width, height);
+		horizontal = height < 2*width;
+		/* This is not that great. Ideally we would have a nice vertical menubar. */
+		if ((shadow_type != GTK_SHADOW_NONE) && horizontal)
+			STYLE_FUNCTION(draw_menubar) (cr, colors, &params, &menubar,
+			                              x, y, width, height);
 	}
 	else if (DETAIL ("button") && CHECK_HINT (GE_HINT_TREEVIEW_HEADER))
 	{
@@ -828,14 +832,26 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	{
 		WidgetParameters  params;
 		ToolbarParameters toolbar;
+		gboolean horizontal;
 
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		clearlooks_set_toolbar_parameters (&toolbar, widget, window, x, y);
 
 		toolbar.style = clearlooks_style->toolbarstyle;
 
-		/* Only draw the shadows on horizontal toolbars */
-		if (shadow_type != GTK_SHADOW_NONE && height < 2*width )
+		if ((DETAIL ("handlebox_bin") || DETAIL ("dockitem_bin")) && GE_IS_BIN (widget))
+		{
+			GtkWidget* child = gtk_bin_get_child ((GtkBin*) widget);
+			/* This is to draw the correct shadow on the handlebox.
+			 * We need to draw it here, as otherwise the handle will not get the
+			 * background. */
+			if (GE_IS_TOOLBAR (child))
+				gtk_widget_style_get (child, "shadow-type", &shadow_type, NULL);
+		}
+		
+		horizontal = height < 2*width;
+		/* This is not that great. Ideally we would have a nice vertical toolbar. */
+		if ((shadow_type != GTK_SHADOW_NONE) && horizontal)
 			STYLE_FUNCTION(draw_toolbar) (cr, colors, &params, &toolbar, x, y, width, height);
 	}
 	else if (DETAIL ("trough"))
